pub struct ApiChatRequest {
pub messages: Vec<ApiChatMessage>,
pub tools: Vec<ApiTool>,
pub tool_choice: Option<ApiToolChoice>,
pub tool_call_protocol: ApiToolCallProtocol,
pub legacy_functions: Vec<ApiFunction>,
pub legacy_function_call: Option<ApiFunctionCallChoice>,
pub response_format: Option<ApiResponseFormat>,
pub stream_options: Option<ApiStreamOptions>,
}Fields
messages: Vec<ApiChatMessage>tools: Vec<ApiTool>tool_choice: Option<ApiToolChoice>tool_call_protocol: ApiToolCallProtocolWire protocol emitted by the model’s chat template for automatic tool calls. Forced/named calls may still use a hard argument grammar and the JSON fallback.
legacy_functions: Vec<ApiFunction>legacy_function_call: Option<ApiFunctionCallChoice>response_format: Option<ApiResponseFormat>stream_options: Option<ApiStreamOptions>Implementations
Sourceimpl ApiChatRequest
impl ApiChatRequest
Sourcepub fn generated_control_token_texts(&self) -> &'static [&'static str]
pub fn generated_control_token_texts(&self) -> &'static [&'static str]
Protocol controls are generatable only when this request can emit a
modern tool call. tool_choice: none must not widen token sampling.
Sourcepub fn generated_response_envelope(&self) -> Option<ResponseCompletionEnvelope>
pub fn generated_response_envelope(&self) -> Option<ResponseCompletionEnvelope>
Alternate complete response envelope available to this request.