pub struct ResponseCompletionEnvelope {
pub open_token_text: String,
pub close_token_text: String,
pub max_envelopes: usize,
}Expand description
A lexical response envelope that can complete an otherwise pending response.
This describes only token boundaries. The product/API layer remains responsible for validating the enclosed payload after generation.
Fields
open_token_text: Stringclose_token_text: Stringmax_envelopes: usizeTrait Implementations
Sourceimpl Clone for ResponseCompletionEnvelope
impl Clone for ResponseCompletionEnvelope
Sourcefn clone(&self) -> ResponseCompletionEnvelope
fn clone(&self) -> ResponseCompletionEnvelope
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResponseCompletionEnvelope
impl Debug for ResponseCompletionEnvelope
Sourceimpl<'de> Deserialize<'de> for ResponseCompletionEnvelope
impl<'de> Deserialize<'de> for ResponseCompletionEnvelope
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResponseCompletionEnvelope
impl StructuralPartialEq for ResponseCompletionEnvelope